@@ -16,8 +16,8 @@ pub struct Page {
 	pub serial: u32,
 	pub seq_num: u32,
 	pub checksum: u32,
-	pub start: usize,
-	pub end: usize,
+	pub start: u64,
+	pub end: u64,
 }
 
 impl Page {
@@ -47,11 +47,11 @@ impl Page {
 	}
 
 	/// Attempts to get a Page from a reader
-	pub fn read<V>(data: &mut V) -> Result<Self>
+	pub fn read<V>(data: &mut V, skip_content: bool) -> Result<Self>
 	where
 		V: Read + Seek,
 	{
-		let start = data.seek(SeekFrom::Current(0))? as usize;
+		let start = data.seek(SeekFrom::Current(0))?;
 
 		let mut sig = [0; 4];
 		data.read_exact(&mut sig)?;
@@ -83,10 +83,17 @@ impl Page {
 		let mut segment_table = vec![0; segments as usize];
 		data.read_exact(&mut segment_table)?;
 
-		let mut content = vec![0; segment_table.iter().map(|&b| b as usize).sum()];
-		data.read_exact(&mut content)?;
+		let mut content: Vec<u8> = Vec::new();
+		let content_len = segment_table.iter().map(|&b| b as i64).sum();
 
-		let end = data.seek(SeekFrom::Current(0))? as usize;
+		if skip_content {
+			data.seek(SeekFrom::Current(content_len))?;
+		} else {
+			content = vec![0; content_len as usize];
+			data.read_exact(&mut content)?;
+		}
+
+		let end = data.seek(SeekFrom::Current(0))?;
 
 		Ok(Page {
 			content,
@@ -112,7 +119,7 @@ impl Page {
 
 		if self_len <= 65025 && self_len + content_len <= 65025 {
 			self.content.extend(content.iter());
-			self.end += content_len;
+			self.end += content_len as u64;
 
 			return None;
 		}
@@ -121,7 +128,7 @@ impl Page {
 			let remaining = 65025 - self_len;
 
 			self.content.extend(content[0..remaining].iter());
-			self.end += remaining;
+			self.end += remaining as u64;
 
 			let mut p = Page {
 				content: content[remaining..].to_vec(),
@@ -131,7 +138,7 @@ impl Page {
 				seq_num: self.seq_num + 1,
 				checksum: 0,
 				start: self.end,
-				end: self.start + content.len(),
+				end: self.start + content.len() as u64,
 			};
 
 			p.gen_crc();
